
User guide
====================================


.. toctree::
   :maxdepth: 1
   :titlesonly:

   read_bufr

Readers
+++++++++

.. toctree::
   :maxdepth: 1

   readers/generic
   readers/flat
   readers/synop
   readers/temp

Miscellaneous
+++++++++++++++

.. toctree::
   :maxdepth: 1
   :titlesonly:

   misc/index


The BUFR format
+++++++++++++++++

.. toctree::
   :maxdepth: 1
   :titlesonly:

   bufr_primer
